@@ -2,7 +2,7 @@
  * GTimer
  *
  * Copyright:
- *	(C) 1998 Craig Knudsen, cknudsen@radix.net
+ *	(C) 1999 Craig Knudsen, cknudsen@radix.net
  *	See accompanying file "COPYING".
  * 
  *	This program is free software; you can redistribute it and/or
@@ -30,6 +30,7 @@
  *	http://www.radix.net/~cknudsen/gtimer/
  *
  * History:
+ *	18-Mar-1999	Internationalization
  *	16-May-1999	Added support for GTK 1.0.
  *	10-May-1998	Removed ifdef for GTK versions before 1.0.0
  *	02-Apr-1998	Fixed bug that caused garbage to appear at the
@@ -46,11 +47,19 @@
 #if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#include <pwd.h>
+#if HAVE_STRING_H
+#include <string.h>
+#endif
 #include <time.h>
 #include <memory.h>
 #include <ctype.h>
 
+#ifdef HAVE_LIBINTL_H
+#include <libintl.h>
+#else
+#define gettext(a)      a
+#endif
+
 #include <gtk/gtk.h>
 
 #include "task.h"
@@ -94,7 +103,7 @@ gpointer data;
       taskAddAnnotation ( td->taskdata->task, taskdir, str );
     free ( str );
     gtk_statusbar_push ( GTK_STATUSBAR ( status ), status_id,
-      "Annotation added" );
+      gettext("Annotation added") );
   }
 
   gtk_grab_remove ( td->window );
@@ -126,7 +135,7 @@ TaskData *taskdata;
   GtkWidget *label, *ok_button, *cancel_button, *hbox;
   GtkStyle *style;
   AnnotateData *td;
-  char *str;
+  char *str, msg[100];
 
   if ( taskdata == NULL )
     return ( NULL );
@@ -134,9 +143,10 @@ TaskData *taskdata;
   td = (AnnotateData *) malloc ( sizeof ( AnnotateData ) );
   td->taskdata = taskdata;
   td->window = annotate_window = gtk_dialog_new ();
-  gtk_window_set_wmclass ( GTK_WINDOW ( td->window ), "GTimer", "gtimer" );
-  gtk_window_set_title (GTK_WINDOW (annotate_window),
-    "GTimer: Add Annotation" );
+  gtk_window_set_wmclass ( GTK_WINDOW ( td->window ), "GTimer",
+    "gtimer" );
+  sprintf ( msg, "GTimer: %s", gettext("Add Annotation") );
+  gtk_window_set_title (GTK_WINDOW (annotate_window), msg );
   gtk_window_position ( GTK_WINDOW(annotate_window), GTK_WIN_POS_MOUSE );
   gtk_grab_add ( annotate_window );
   gtk_widget_realize ( annotate_window );
@@ -145,8 +155,9 @@ TaskData *taskdata;
   gtk_box_pack_start ( GTK_BOX ( GTK_DIALOG (annotate_window)->vbox ),
     hbox, FALSE, FALSE, 5 );
 
-  str = (char *) malloc ( strlen ( taskdata->task->name ) + 25 );
-  sprintf ( str, "Enter annotation for\n%s", taskdata->task->name );
+  str = (char *) malloc ( strlen ( taskdata->task->name ) + 100 );
+  sprintf ( str, "%s\n%s", gettext("Enter annotation for"),
+    taskdata->task->name );
   label = gtk_label_new ( str );
   free ( str );
   gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 5 );
@@ -175,7 +186,7 @@ TaskData *taskdata;
   /* add command buttons */
   /*tooltips = gtk_tooltips_new ();*/
 
-  ok_button = gtk_button_new_with_label ("Ok");
+  ok_button = gtk_button_new_with_label ( gettext("Ok") );
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (annotate_window)->action_area),
     ok_button, TRUE, TRUE, 5);
   gtk_signal_connect (GTK_OBJECT (ok_button), "clicked",
@@ -186,7 +197,7 @@ TaskData *taskdata;
   /*gtk_tooltips_set_tips (tooltips, ok_button,
     "Save this task" );*/
 
-  cancel_button = gtk_button_new_with_label ("Cancel");
+  cancel_button = gtk_button_new_with_label ( gettext("Cancel") );
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (annotate_window)->action_area),
     cancel_button, TRUE, TRUE, 5);
   gtk_signal_connect (GTK_OBJECT (cancel_button), "clicked",
