@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1998 Craig Knudsen, cknudsen@radix.net
+ * Copyright (C) 1999 Craig Knudsen, cknudsen@radix.net
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -36,10 +36,10 @@
 #if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#if HAVE_FCNTL_H
 #include <fcntl.h>
-#endif
+#if HAVE_STRING_H
 #include <string.h>
+#endif
 
 #ifdef GTIMER_MEMDEBUG
 #include "memdebug/memdebug.h"
