@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1998 Craig Knudsen, cknudsen@radix.net
+ * Copyright (C) 1999 Craig Knudsen, cknudsen@radix.net
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -44,12 +44,15 @@
 #define CONFIG_PRINT			"print"
 #define CONFIG_IDLE			"idle"
 #define CONFIG_IDLE_ON			"idle-on"
+#define CONFIG_TOOLBAR_STATUS		"toolbar-status"
 #define CONFIG_AUTOSAVE			"autosave"
+#define CONFIG_ANIMATE			"animate"
 #define CONFIG_MAIN_WINDOW_WIDTH	"win_width"
 #define CONFIG_MAIN_WINDOW_HEIGHT	"win_height"
 #define CONFIG_MAIN_WINDOW_TASK_WIDTH	"list_task_width"
 #define CONFIG_MAIN_WINDOW_TODAY_WIDTH	"list_today_width"
 #define CONFIG_MAIN_WINDOW_TOTAL_WIDTH	"list_total_width"
+#define CONFIG_NEXT_VERSION_CHECK	"next_version_check"
 
 /* default values */
 #ifdef CONFIG_DEFAULTS
@@ -60,8 +63,11 @@ static char *default_config[] = {
   CONFIG_IDLE, "300",
   CONFIG_IDLE_ON, "1",
   CONFIG_AUTOSAVE, "1",
+  CONFIG_ANIMATE, "1",
+  CONFIG_TOOLBAR_STATUS, "1",
   CONFIG_MAIN_WINDOW_WIDTH, "500",
   CONFIG_MAIN_WINDOW_HEIGHT, "400",
+  CONFIG_NEXT_VERSION_CHECK, "0",
   NULL,
 };
 #endif
