@@ -2,7 +2,7 @@
  * GTimer
  *
  * Copyright:
- *	(C) 1998 Craig Knudsen, cknudsen@radix.net
+ *	(C) 1999 Craig Knudsen, cknudsen@radix.net
  *	See accompanying file "COPYING".
  * 
  *	This program is free software; you can redistribute it and/or
@@ -30,6 +30,10 @@
  *	http://www.radix.net/~cknudsen/gtimer/
  *
  * History:
+ *	09-Mar-2000	Added optional third button for confirm windows.
+ *	07-Mar-2000	Added create_confirm_toplevel ()
+ *	25-Mar-1999	Added use of gtk_window_set_transient_for() for
+ *			GTK 1.1 or later.
  *	18-Mar-1998	Added calls to gtk_window_set_wmclass so the windows
  *			behave better for window managers.
  *	16-Mar-1998	Changed application/about icon.
@@ -43,7 +47,6 @@
 #if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#include <pwd.h>
 #include <time.h>
 #include <memory.h>
 #include <ctype.h>
@@ -62,6 +65,8 @@
 #include "icons/confirm.xpm"
 #include "icons/about.xpm"
 
+extern GtkWidget *main_window;
+
 static GdkPixmap *error_icon = NULL, *confirm_icon = NULL,
   *gtimer_icon = NULL;
 static GdkBitmap *error_mask, *confirm_mask, *gtimer_mask;
@@ -71,6 +76,7 @@ typedef struct {
   GtkWidget *window;
   void (*ok_callback)();
   void (*cancel_callback)();
+  void (*third_callback)();
 } ConfirmData;
 
 
@@ -102,41 +108,71 @@ gpointer data;
 }
 
 
+static void confirm_third_callback ( widget, data )
+GtkWidget *widget;
+gpointer data;
+{
+  ConfirmData *cd = (ConfirmData *) data;
+
+  gtk_grab_remove ( cd->window );
+  if ( cd->third_callback )
+    cd->third_callback ( widget, (gpointer)cd->callback_data );
+  gtk_widget_destroy ( cd->window );
+  free ( cd );
+}
+
+
+
+
+
 
 
 /*
-** Create the add/edit window.
-** It's an add if taskdata is NULL.
+** Create the confirm window.
 */
-GtkWidget *create_confirm_window ( type, title, text, ok_text, cancel_text,
-  ok_callback, cancel_callback,
+static GtkWidget *create_window ( type, is_modal, title, text,
+  ok_text, cancel_text, third_text,
+  ok_callback, cancel_callback, third_callback,
   callback_data )
 enum_confirm_type type;
+int is_modal;
 char *title;
 char *text;
-char *ok_text, *cancel_text;
+char *ok_text, *cancel_text, *third_text;
 void (*ok_callback)();
 void (*cancel_callback)();
+void (*third_callback)();
 char *callback_data;
 {
   GtkWidget *window;
   /*GtkWidget *vbox, *hbox, *table;*/
   GtkWidget *table;
-  GtkWidget *pixmap, *label, *ok_button, *cancel_button;
+  GtkWidget *pixmap, *label, *ok_button, *cancel_button, *third_button;
   ConfirmData *cd;
   GdkPixmap *icon = NULL, *mask = NULL;
+  char *title2;
 
   cd = (ConfirmData *) malloc ( sizeof ( ConfirmData ) );
   cd->callback_data = callback_data;
   cd->ok_callback = ok_callback;
   cd->cancel_callback = cancel_callback;
+  cd->third_callback = third_callback;
   cd->window = window = gtk_dialog_new ();
   gtk_window_set_wmclass ( GTK_WINDOW ( cd->window ), "GTimer", "gtimer" );
-  gtk_window_set_title (GTK_WINDOW (window), title );
+  title2 = (char *) malloc ( strlen ( title ) + 10 );
+  sprintf ( title2, "GTimer: %s", title );
+  gtk_window_set_title (GTK_WINDOW (window), title2 );
+  free ( title2 );
   gtk_window_position ( GTK_WINDOW(window), GTK_WIN_POS_MOUSE );
   gtk_grab_add ( window );
   gtk_widget_realize ( window );
 
+#if GTK_VERSION >= 10100
+  if ( is_modal )
+    gtk_window_set_transient_for ( GTK_WINDOW ( window ),
+      GTK_WINDOW ( main_window ) );
+#endif
+
   table = gtk_table_new (1, 2, FALSE);
   gtk_table_set_row_spacings (GTK_TABLE (table), 4);
   gtk_table_set_col_spacings (GTK_TABLE (table), 8);
@@ -215,9 +251,63 @@ char *callback_data;
     gtk_widget_show (cancel_button);
   }
 
+  if ( third_text ) {
+    third_button = gtk_button_new_with_label ( third_text );
+    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->action_area),
+      third_button, FALSE, FALSE, 10);
+    if ( confirm_third_callback != NULL )
+      gtk_signal_connect (GTK_OBJECT (third_button), "clicked",
+        GTK_SIGNAL_FUNC (confirm_third_callback), cd);
+    gtk_widget_show (third_button);
+  }
+
   gtk_widget_show (window);
 
   return ( window );
 }
 
 
+
+
+/*
+** Create a toplevel confirm window.
+*/
+GtkWidget *create_confirm_toplevel ( type, title, text,
+  ok_text, cancel_text, third_text,
+  ok_callback, cancel_callback, third_callback,
+  callback_data )
+enum_confirm_type type;
+char *title;
+char *text;
+char *ok_text, *cancel_text, *third_text;
+void (*ok_callback)();
+void (*cancel_callback)();
+void (*third_callback)();
+char *callback_data;
+{
+  return create_window ( type, FALSE, title, text, ok_text,
+    cancel_text, third_text, ok_callback, cancel_callback, third_callback,
+    callback_data );
+}
+
+/*
+** Create a modal confirm window.
+*/
+GtkWidget *create_confirm_window ( type, title, text,
+  ok_text, cancel_text, third_text,
+  ok_callback, cancel_callback, third_callback,
+  callback_data )
+enum_confirm_type type;
+char *title;
+char *text;
+char *ok_text, *cancel_text, *third_text;
+void (*ok_callback)();
+void (*cancel_callback)();
+void (*third_callback)();
+char *callback_data;
+{
+  return create_window ( type, TRUE, title, text,
+    ok_text, cancel_text, third_text,
+    ok_callback, cancel_callback, third_callback, callback_data );
+}
+
