@@ -2,7 +2,7 @@
  * GTimer
  *
  * Copyright:
- *	(C) 1998 Craig Knudsen, cknudsen@radix.net
+ *	(C) 1999 Craig Knudsen, cknudsen@radix.net
  *	See accompanying file "COPYING".
  * 
  *	This program is free software; you can redistribute it and/or
@@ -30,6 +30,10 @@
  *	http://www.radix.net/~cknudsen/gtimer/
  *
  * History:
+ *	09-Mar-2000	Changed release to 1.1.5
+ *	09-Mar-2000	Added args to confirm_create_window()
+ *	04-May-1999	Changed release to 1.1.4
+ *	03-May-1999	Changed release to 1.1.3
  *	17-Mar-1999	Changed release to 1.1.2
  *	24-Feb-1999	Changed release to 1.1.1
  *	02-Feb-1999	Changed release to 1.1.0
@@ -53,15 +57,20 @@
 
 /* Note: we could use "VERSION" produced from autoconf, but I like
    to also have the version date, so I'll just edit this by hand. */
-#define GTIMER_VERSION		"1.1.2"
-#define GTIMER_VERSION_DATE	"17 Mar 1999"
+#define GTIMER_VERSION		"1.1.5"
+#define GTIMER_VERSION_DATE	"09 Mar 2000"
 #define GTIMER_URL		"http://www.radix.net/~cknudsen/gtimer/"
-#define GTIMER_COPYRIGHT	"Copyright (C) 1999 Craig Knudsen"
+#define GTIMER_COPYRIGHT	"Copyright (C) 2000 Craig Knudsen"
 
 #define GTIMER_STATUS_ID	"status-update"
 
 #define GTIMER_TASK_OPTION_HIDDEN	0x0001
 
+/* URL to check for new version */
+#define GTIMER_VERSION_CHECK_SERVER	"www.radix.net"
+#define GTIMER_VERSION_CHECK_PORT	80
+#define GTIMER_VERSION_CHECK_PATH	"/~cknudsen/gtimer/latest_version.txt"
+
 typedef enum {
   CONFIRM_ABOUT,
   CONFIRM_ERROR,
@@ -99,7 +108,11 @@ void save_all ();
 
 void update_list ();
 
+#ifdef __GTK_H__
+
+#ifndef WIN32
 void set_x_error_handler ();
+#endif
 
 GtkWidget *create_edit_window ( TaskData *taskdata );
 
@@ -109,18 +122,35 @@ GtkWidget *create_report_window ( report_type type );
 
 GtkWidget *create_unhide_window ( );
 
+void display_changelog ( );
+
 GtkWidget *create_confirm_window (
   enum_confirm_type type,
   char *title,
   char *text,
   char *ok_text,
   char *cancel_text,
+  char *third_text,
   void (*ok_callback)(),
   void (*cancel_callback)(),
+  void (*third_callback)(),
   char *callback_data
 );
+
+GtkWidget *create_confirm_toplevel (
+  enum_confirm_type type,
+  char *title,
+  char *text,
+  char *ok_text,
+  char *cancel_text,
+  char *third_text,
+  void (*ok_callback)(),
+  void (*cancel_callback)(),
+  void (*third_callback)(),
+  char *callback_data
+);
+
+#endif /* __GTK_H__ */
   
-
-
 #endif /* _GTIMER_H */
 
