@@ -2,7 +2,7 @@
  * GTimer
  *
  * Copyright:
- *	(C) 1998 Craig Knudsen, cknudsen@radix.net
+ *	(C) 1999 Craig Knudsen, cknudsen@radix.net
  *	See accompanying file "COPYING".
  * 
  *	This program is free software; you can redistribute it and/or
@@ -30,6 +30,10 @@
  *	http://www.radix.net/~cknudsen/gtimer/
  *
  * History:
+ *	09-Mar-2000	Updated calls to create_confirm_window()
+ *	25-Mar-1999	Added use of gtk_window_set_transient_for() for
+ *			GTK 1.1 or later.
+ *	18-Mar-1999	Internationalization
  *	02-Feb-1999	gtk 1.1 support
  *	04-Jan-1999	Eek...  Fixed bug for "last month" reports when
  *			run in Jan.
@@ -82,7 +86,6 @@
 #if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#include <pwd.h>
 #include <time.h>
 #include <memory.h>
 #include <ctype.h>
@@ -93,6 +96,12 @@
 
 #include <gtk/gtk.h>
 
+#ifdef HAVE_LIBINTL_H
+#include <libintl.h>
+#else
+#define gettext(a)      a
+#endif
+
 #include "task.h"
 #include "gtimer.h"
 #include "config.h"
@@ -111,6 +120,8 @@ extern TaskData **visible_tasks;
 extern int num_visible_tasks;
 extern int config_midnight_offset;
 extern GtkWidget *main_window;
+extern GdkPixmap *appicon2;
+extern GdkPixmap *appicon2_mask;
 
 /* Report types */
 #define REPORT_RANGE_TODAY              0
@@ -295,10 +306,11 @@ gpointer data;
   fd = open ( file, O_WRONLY | O_CREAT | O_TRUNC, 0644 );
   if ( fd <= 0 ) {
     msg = (char *) malloc ( strlen ( file ) + 100 );
-    sprintf ( msg, "Error %d writing to file\n%s",
-      errno, file );
+    sprintf ( msg, "%s %d %s\n%s", gettext ("Error"),
+      errno, gettext("writing to file"), file );
     create_confirm_window ( CONFIRM_ERROR,
-      "GTimer: Error", msg, "Ok", NULL, NULL, NULL, NULL );
+      gettext("Error"), msg, gettext("Ok"), NULL, NULL,
+      NULL, NULL, NULL, NULL );
     free ( msg );
   } else {
     write ( fd, drd->text, strlen ( drd->text ) );
@@ -314,11 +326,13 @@ GtkWidget *widget;
 gpointer data;
 {
   DisplayReportData *drd = (DisplayReportData *)data;
+  char msg[100];
 
   if ( drd->filesel )
     return;
 
-  drd->filesel = gtk_file_selection_new ( "TaskTime: Save Report" );
+  sprintf ( msg, "GTimer: %s", gettext("Save Report") );
+  drd->filesel = gtk_file_selection_new ( msg );
 
   gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION(drd->filesel)->ok_button),
     "clicked", GTK_SIGNAL_FUNC (display_text_results_save_ok_callback), drd);
@@ -343,7 +357,9 @@ gpointer data;
   ptr = gtk_entry_get_text ( GTK_ENTRY(drd->printentry) );
   if ( ! ptr || ! strlen ( ptr ) ) {
     create_confirm_window ( CONFIRM_ERROR,
-      "GTimer: Error", "You must enter a print command", "Ok",
+      gettext("Error"),
+      gettext("You must enter a print command"),
+      gettext("Ok"), NULL, NULL,
       NULL, NULL, NULL, NULL );
     return;
   }
@@ -352,10 +368,11 @@ gpointer data;
   fd = open ( tempfile, O_WRONLY | O_CREAT | O_TRUNC, 0644 );
   if ( fd <= 0 ) {
     msg = (char *) malloc ( strlen ( tempfile ) + 100 );
-    sprintf ( msg, "Error %d writing to file\n%s",
-      errno, tempfile );
+    sprintf ( msg, "%s %d %s\n%s", gettext("Error"),
+      errno, gettext("writing to file"), tempfile );
     create_confirm_window ( CONFIRM_ERROR,
-      "GTimer: Error", msg, "Ok", NULL, NULL, NULL, NULL );
+      gettext("Error"), msg, gettext("Ok"), NULL, NULL,
+      NULL, NULL, NULL, NULL );
     free ( msg );
   } else {
     write ( fd, drd->text, strlen ( drd->text ) );
@@ -363,7 +380,9 @@ gpointer data;
     sprintf ( cmd, "cat %s | %s", tempfile, ptr );
     if ( system ( cmd ) ) {
       create_confirm_window ( CONFIRM_ERROR,
-        "GTimer: Error", "Error printing", "Ok", NULL, NULL, NULL, NULL );
+        gettext("Error"), gettext("Error printing"),
+        gettext("Ok"), NULL, NULL,
+        NULL, NULL, NULL, NULL );
     } else {
       configSetAttribute ( CONFIG_PRINT, ptr );
       gtk_grab_remove ( drd->printwin );
@@ -391,7 +410,7 @@ GtkWidget *widget;
 gpointer data;
 {
   DisplayReportData *drd = (DisplayReportData *)data;
-  char *ptr;
+  char *ptr, msg[100];
   GtkWidget *hbox, *label, *button;
 
   if ( drd->printwin )
@@ -399,17 +418,25 @@ gpointer data;
 
   drd->printwin = gtk_dialog_new ();
   gtk_window_set_wmclass ( GTK_WINDOW ( drd->printwin ), "GTimer", "gtimer" );
-  gtk_window_set_title (GTK_WINDOW (drd->printwin),
-    "GTimer: Print Report" );
+  sprintf ( msg, "GTimer: %s", gettext("Print Report") );
+  gtk_window_set_title (GTK_WINDOW (drd->printwin), msg );
   gtk_window_position ( GTK_WINDOW(drd->printwin), GTK_WIN_POS_MOUSE );
   gtk_grab_add ( drd->printwin );
   gtk_widget_realize ( drd->printwin );
+  gdk_window_set_icon ( GTK_WIDGET ( drd->printwin )->window,
+    NULL, appicon2, appicon2_mask );
+
+#if GTK_VERSION >= 10100
+  gtk_window_set_transient_for ( GTK_WINDOW ( drd->printwin ),
+    GTK_WINDOW ( drd->window ) );
+#endif
 
   hbox = gtk_hbox_new ( TRUE, 5 );
   gtk_box_pack_start ( GTK_BOX ( GTK_DIALOG (drd->printwin)->vbox ),
     hbox, FALSE, FALSE, 5 );
 
-  label = gtk_label_new ( "Print Command: " );
+  sprintf ( msg, "%s: ", gettext("Print Command") );
+  label = gtk_label_new ( msg );
   gtk_box_pack_start ( GTK_BOX ( hbox ), label, FALSE, FALSE, 5 );
   gtk_widget_show ( label );
 
@@ -421,7 +448,7 @@ gpointer data;
 
   gtk_widget_show ( hbox );
 
-  button = gtk_button_new_with_label ("Ok");
+  button = gtk_button_new_with_label ( gettext("Ok") );
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (drd->printwin)->action_area),
     button, TRUE, TRUE, 5);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
@@ -430,7 +457,7 @@ gpointer data;
   gtk_widget_grab_default (button);
   gtk_widget_show (button);
 
-  button = gtk_button_new_with_label ("Cancel");
+  button = gtk_button_new_with_label ( gettext("Cancel") );
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (drd->printwin)->action_area),
     button, TRUE, TRUE, 5);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
@@ -450,14 +477,19 @@ char *text;
   GtkWidget *window, *hbox, *button, *textarea, *vscrollbar;
   GtkStyle *style;
   /*GtkTooltips *tooltips;*/
+  char msg[100];
 
   drd = (DisplayReportData *) malloc ( sizeof ( DisplayReportData ) );
   memset ( drd, '\0', sizeof ( DisplayReportData ) );
   drd->text = text;
 
   drd->window = window = gtk_dialog_new ();
-  gtk_window_set_title (GTK_WINDOW (window), "GTimer: Report" );
+  sprintf ( msg, "GTimer: %s", gettext ("Report") );
+  gtk_window_set_title (GTK_WINDOW (window), msg );
   gtk_window_set_wmclass ( GTK_WINDOW ( drd->window ), "GTimer", "gtimer" );
+  gtk_widget_realize ( drd->window );
+  gdk_window_set_icon ( GTK_WIDGET ( drd->window )->window,
+    NULL, appicon2, appicon2_mask );
 
   hbox = gtk_hbox_new ( FALSE, 2 );
   gtk_box_pack_start ( GTK_BOX ( GTK_DIALOG (window)->vbox ),
@@ -493,21 +525,21 @@ char *text;
 
   gtk_widget_show ( hbox );
 
-  button = gtk_button_new_with_label ("Save");
+  button = gtk_button_new_with_label ( gettext("Save") );
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->action_area),
     button, TRUE, FALSE, 10);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
     GTK_SIGNAL_FUNC (display_text_results_save_callback), drd);
   gtk_widget_show (button);
 
-  button = gtk_button_new_with_label ("Print");
+  button = gtk_button_new_with_label ( gettext("Print") );
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->action_area),
     button, TRUE, FALSE, 10);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
     GTK_SIGNAL_FUNC (display_text_results_print_callback), drd);
   gtk_widget_show (button);
 
-  button = gtk_button_new_with_label ("Ok");
+  button = gtk_button_new_with_label ( gettext("Ok") );
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->action_area),
     button, TRUE, FALSE, 10);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
@@ -690,12 +722,12 @@ int is_last;
     switch ( format ) {
       case REPORT_OUTPUT_TEXT:
         fprintf ( fp, "---------\n" );
-        fprintf ( fp, "%3d:%02d:%02d - %s\n", h, m, s, "Total" );
+        fprintf ( fp, "%3d:%02d:%02d - %s\n", h, m, s, gettext("Total") );
         break;
       case REPORT_OUTPUT_HTML:
         fprintf ( fp, "<TR><TD ALIGN=\"right\">%d:%02d:%02d</TD>",
           h, m, s );
-        fprintf ( fp, "<TD>Total</TD></TR>\n" );
+        fprintf ( fp, "<TD>%s</TD></TR>\n", gettext("Total") );
         break;
     }
   }
@@ -709,15 +741,15 @@ int is_last;
         if ( ! found ) {
           switch ( format ) {
             case REPORT_OUTPUT_TEXT:
-              fprintf ( fp, "\nWeek %s to %02d/%02d/%d %s\n",
-                seltasks[loop]->week_start, mon, mday, year,
+              fprintf ( fp, "\n%s %s %s %02d/%02d/%d %s\n", gettext("Week"),
+                seltasks[loop]->week_start, gettext("to"), mon, mday, year,
                 weekdays[wday] );
               fprintf ( fp, "-------------------------------------\n" );
               break;
             case REPORT_OUTPUT_HTML:
               fprintf ( fp, "<TR><TH COLSPAN=\"%d\">", ncols + 1 );
-              fprintf ( fp, "Week %s to %02d/%02d/%d %s",
-                seltasks[loop]->week_start, mon, mday, year,
+              fprintf ( fp, "%s %s %s %02d/%02d/%d %s", gettext("Week"),
+                seltasks[loop]->week_start, gettext("to"), mon, mday, year,
                 weekdays[wday] );
               fprintf ( fp, "</TH></TR>\n" );
               break;
@@ -784,12 +816,12 @@ int is_last;
         if ( ! found ) {
           switch ( format ) {
             case REPORT_OUTPUT_TEXT:
-              fprintf ( fp, "\nMonth %02d/%d\n", mon, year );
+              fprintf ( fp, "\n%s %02d/%d\n", gettext("Month"), mon, year );
               fprintf ( fp, "-------------------------------------\n" );
               break;
             case REPORT_OUTPUT_HTML:
-              fprintf ( fp, "<TR><TH COLSPAN=\"%d\">Month %02d/%d</TH></TR>",
-                ncols + 1, mon, year );
+              fprintf ( fp, "<TR><TH COLSPAN=\"%d\">%s %02d/%d</TH></TR>",
+                ncols + 1, gettext("Month"), mon, year );
               break;
           }
           found = 1;
@@ -851,12 +883,12 @@ int is_last;
         if ( ! found ) {
           switch ( format ) {
             case REPORT_OUTPUT_TEXT:
-              fprintf ( fp, "\nYear %d\n", year );
+              fprintf ( fp, "\n%s %d\n", gettext("Year"), year );
               fprintf ( fp, "-------------------------------------\n" );
               break;
             case REPORT_OUTPUT_HTML:
-              fprintf ( fp, "<TR><TH COLSPAN=\"%d\">Year %d</TH></TR>\n",
-                ncols + 1, year );
+              fprintf ( fp, "<TR><TH COLSPAN=\"%d\">%s %d</TH></TR>\n",
+                ncols + 1, gettext("Year"), year );
               break;
           }
           found = 1;
@@ -916,12 +948,12 @@ int is_last;
         if ( ! found ) {
           switch ( format ) {
             case REPORT_OUTPUT_TEXT:
-              fprintf ( fp, "\nTotals\n" );
+              fprintf ( fp, "\n%s\n", gettext("Totals") );
               fprintf ( fp, "-------------------------------------\n" );
               break;
             case REPORT_OUTPUT_HTML:
-              fprintf ( fp, "<TR><TH COLSPAN=\"%d\">Totals</TH></TR>\n",
-                ncols + 1 );
+              fprintf ( fp, "<TR><TH COLSPAN=\"%d\">%s</TH></TR>\n",
+                ncols + 1, gettext("Totals") );
               break;
           }
           found = 1;
@@ -1010,8 +1042,10 @@ char *text;
   path = get_client_path ( "netscape" );
   if ( path == NULL ) {
     create_confirm_window ( CONFIRM_ERROR,
-      "GTimer: Error", "Could not find \"netscape\"\nin your path.",
-      "Ok", NULL, NULL, NULL, NULL );
+      gettext("Error"),
+      gettext("Could not find \"netscape\"\nin your path."),
+      gettext("Ok"), NULL, NULL,
+      NULL, NULL, NULL, NULL );
   }
 
   sprintf ( tempfile, "/tmp/gtimer-%d.html", (int) random () % 1000 );
@@ -1025,8 +1059,9 @@ char *text;
     path, tempfile );
   if ( system ( command ) != 0 ) {
     create_confirm_window ( CONFIRM_ERROR,
-      "GTimer: Error", "Error communicating with Netscape.\n",
-      "Ok", NULL, NULL, NULL, NULL );
+      gettext("Error"), gettext("Error communicating with Netscape."),
+      gettext("Ok"), NULL, NULL,
+      NULL, NULL, NULL, NULL );
   }
 
   free ( path );
@@ -1058,10 +1093,10 @@ gpointer data;
 
   if ( ! selected ) {
     create_confirm_window ( CONFIRM_ERROR,
-      "Error",
-      "You have not selected any tasks",
-      "Ok", NULL,
-      NULL, NULL,
+      gettext("Error"),
+      gettext("You have not selected any tasks"),
+      gettext("Ok"), NULL, NULL,
+      NULL, NULL, NULL,
       NULL );
     return;
   }
@@ -1089,10 +1124,10 @@ gpointer data;
 
   if ( ! rd->include_hours && ! rd->include_annotations ) {
     create_confirm_window ( CONFIRM_ERROR,
-      "Error",
-      "You must select either \"include hours\"\nor \"include annotations\".",
-      "Ok", NULL,
-      NULL, NULL,
+      gettext("Error"),
+      gettext("You must select either \"include hours\"\nor \"include annotations\"."),
+      gettext("Ok"), NULL, NULL,
+      NULL, NULL, NULL,
       NULL );
     return;
   }
@@ -1140,10 +1175,10 @@ gpointer data;
   fp = fopen ( tempfile, "w" );
   if ( ! fp ) {
     create_confirm_window ( CONFIRM_ERROR,
-      "Error",
-      "Error opening temporary file",
-      "Ok", NULL,
-      NULL, NULL,
+      gettext("Error"),
+      gettext("Error opening temporary file"),
+      gettext("Ok"), NULL, NULL,
+      NULL, NULL, NULL,
       NULL );
     free ( tempfile );
     for ( loop = 0; loop < num_visible_tasks; loop++ )
@@ -1192,7 +1227,8 @@ gpointer data;
   }
 
   if ( format == REPORT_OUTPUT_HTML ) {
-    fprintf ( fp, "<HTML><HEAD><TITLE>GTimer Report</TITLE></HEAD>\n" );
+    fprintf ( fp, "<HTML><HEAD><TITLE>GTimer %s</TITLE></HEAD>\n",
+      gettext("Report") );
     fprintf ( fp, "<BODY BGCOLOR=\"#FFFFFF\">\n" );
     fprintf ( fp, "<TABLE BORDER=2>\n" );
     ncols = 1;
@@ -1209,7 +1245,8 @@ gpointer data;
   }
 
   if ( format == REPORT_OUTPUT_HTML ) {
-    fprintf ( fp, "</TABLE><P><HR><FONT SIZE=\"-1\">Generated by " );
+    fprintf ( fp, "</TABLE><P><HR><FONT SIZE=\"-1\">%s ",
+      gettext("Generated by") );
     fprintf ( fp, "<A HREF=\"%s\">GTimer v%s (%s)</A>.\n",
       GTIMER_URL, GTIMER_VERSION, GTIMER_VERSION_DATE );
     fprintf ( fp, "</BODY></HTML>\n" );
@@ -1224,7 +1261,7 @@ gpointer data;
     if ( ret >= 0 )
       text[ret] = '\0';
     else
-      sprintf ( text, "Error reading %s\n", tempfile );
+      sprintf ( text, "%s %s\n", gettext("Error reading"), tempfile );
     switch ( format ) {
       case REPORT_OUTPUT_TEXT:
         display_text_results ( text );
@@ -1370,16 +1407,20 @@ report_type type;
   ReportData *rd;
   GList *items = NULL;
   int loop;
+  char msg[100];
 
   rd = (ReportData *) malloc ( sizeof ( ReportData ) );
   memset ( rd, '\0', sizeof ( ReportData ) );
   rd->type = type;
   rd->window = report_window = gtk_dialog_new ();
   gtk_window_set_wmclass ( GTK_WINDOW ( rd->window ), "GTimer", "gtimer" );
-  gtk_window_set_title (GTK_WINDOW (report_window), "GTimer: Report" );
+  sprintf ( msg, "GTimer: %s", gettext("Report") );
+  gtk_window_set_title (GTK_WINDOW (report_window), msg );
   gtk_window_position ( GTK_WINDOW(report_window), GTK_WIN_POS_MOUSE );
   gtk_grab_add ( report_window );
   gtk_widget_realize ( report_window );
+  gdk_window_set_icon ( GTK_WIDGET ( rd->window )->window,
+    NULL, appicon2, appicon2_mask );
 
   table = gtk_table_new ( 3, 2, FALSE );
   gtk_table_set_row_spacings (GTK_TABLE (table), 4);
@@ -1401,7 +1442,7 @@ report_type type;
   gtk_widget_show ( rd->time_menu );
 
 
-  label = gtk_label_new ( "Format: " );
+  label = gtk_label_new ( gettext("Format: ") );
   gtk_table_attach_defaults ( GTK_TABLE (table), label, 0, 1, 1, 2 );
   gtk_widget_show ( label );
 
@@ -1413,7 +1454,7 @@ report_type type;
   gtk_table_attach_defaults ( GTK_TABLE (table), rd->output_menu, 1, 2, 1, 2 );
   gtk_widget_show ( rd->output_menu );
 
-  label = gtk_label_new ( "Data: " );
+  label = gtk_label_new ( gettext("Data: ") );
   gtk_table_attach_defaults ( GTK_TABLE (table), label, 0, 1, 2, 3 );
   gtk_widget_show ( label );
 
@@ -1427,7 +1468,7 @@ report_type type;
 
   gtk_widget_show ( table );
 
-  label = gtk_label_new ( "Tasks to include:" );
+  label = gtk_label_new ( gettext("Tasks to include:") );
   gtk_label_set_justify ( GTK_LABEL ( label ), GTK_JUSTIFY_LEFT );
   gtk_box_pack_start ( GTK_BOX ( GTK_DIALOG (report_window)->vbox ),
     label, FALSE, FALSE, 2 );
@@ -1476,7 +1517,7 @@ report_type type;
 
   gtk_box_set_homogeneous ( GTK_BOX ( GTK_DIALOG (report_window)->action_area ),
     1 );
-  button = gtk_button_new_with_label ("Ok");
+  button = gtk_button_new_with_label ( gettext("Ok") );
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (report_window)->action_area),
     button, TRUE, FALSE, 2);
   gtk_box_set_spacing ( GTK_BOX (GTK_DIALOG (report_window)->action_area),
@@ -1488,7 +1529,7 @@ report_type type;
   gtk_widget_show (button);
   /*gtk_tooltips_set_tips (tooltips, button, "Generate a report" );*/
 
-  button = gtk_button_new_with_label ("Cancel");
+  button = gtk_button_new_with_label ( gettext("Cancel") );
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (report_window)->action_area),
     button, TRUE, FALSE, 2);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
@@ -1497,7 +1538,7 @@ report_type type;
   /*gtk_tooltips_set_tips (tooltips, button,
     "Cancel without generating a report" );*/
 
-  button = gtk_button_new_with_label ("Select all");
+  button = gtk_button_new_with_label ( gettext("Select all") );
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (report_window)->action_area),
     button, TRUE, FALSE, 2);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
@@ -1505,7 +1546,7 @@ report_type type;
   gtk_widget_show (button);
   /*gtk_tooltips_set_tips (tooltips, button, "Select all tasks" );*/
 
-  button = gtk_button_new_with_label ("Select none");
+  button = gtk_button_new_with_label ( gettext("Select none") );
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (report_window)->action_area),
     button, TRUE, FALSE, 2);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
