@@ -2,7 +2,7 @@
  * Routines for dealing with tasks
  *
  * Copyright:
- *	(C) 1998 Craig Knudsen, cknudsen@radix.net
+ *	(C) 1999 Craig Knudsen, cknudsen@radix.net
  *	See accompanying file "COPYING".
  * 
  *	This program is free software; you can redistribute it and/or
@@ -21,17 +21,23 @@
  *	Suite 330, Boston, MA  02111-1307, USA
  *
  * History:
- *	11-Nov-98	Added support for options
- *	23-Apr-98	Added new function: taskClearAll
- *	22-Mar-98	Added an extra argument to TaskGetAnnotationEntries
+ *	09-Mar-2000	Added functions to allow for restoring to
+ *			a previous state: taskMark(), taskMarkAll(),
+ *			taskRestore(), taskRestoreAll()
+ *	25-Mar-1999	Lots of WIN32 patches made by
+ *			Thomas Epperly <Thomas.Epperly@aspentech.com>
+ *	18-Mar-1999	Internationalization
+ *	11-Nov-1998	Added support for options
+ *	23-Apr-1998	Added new function: taskClearAll
+ *	22-Mar-1998	Added an extra argument to TaskGetAnnotationEntries
  *			for time offset.
- *	15-Mar-98	Debugged all malloc/free and found one place
+ *	15-Mar-1998	Debugged all malloc/free and found one place
  *			where free() was not called.
- *	15-Mar-98	Fixed bug that caused SIGSEGV.  Only appeared
+ *	15-Mar-1998	Fixed bug that caused SIGSEGV.  Only appeared
  *			if one more tasks (but not the last one) were
  *			deleted.
- *	15-Mar-98	Added new function: taskAddAnnotation
- *	11-Mar-98	Changed functions to K&R style
+ *	15-Mar-1998	Added new function: taskAddAnnotation
+ *	11-Mar-1998	Changed functions to K&R style
  *
  */
 
@@ -42,7 +48,11 @@
 #if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
+#ifdef WIN32
+#include <io.h>
+#else
 #include <dirent.h>
+#endif
 #include <errno.h>
 #include <malloc.h>
 #include <string.h>
@@ -51,6 +61,12 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
+#ifdef HAVE_LIBINTL_H
+#include <libintl.h>
+#else
+#define gettext(a)	a
+#endif
+
 #include "task.h"
 
 #ifdef GTIMER_MEMDEBUG
@@ -63,6 +79,17 @@ static int max_task = -1;
 static int last_number = -1;
 
 
+#ifdef WIN32
+static int valid_name ( filename )
+char *filename;
+{
+  while ( *filename && isdigit ( *filename ) )
+    filename++;
+  return ( ! strcmp ( filename, ".task" ) );
+}
+#endif
+
+
 /*
 ** Add a task.
 */
@@ -124,6 +151,75 @@ char *name;
 }
 
 
+/*
+** Mark the current time in a task.  We can then use taskRestore()
+** to restore the state of the task to what it was when this function
+** was called.
+*/
+void taskMark ( task )
+Task *task;
+{
+  int i;
+
+  for ( i = 0; i < task->num_entries; i++ ) {
+    task->entries[i]->marked_seconds = task->entries[i]->seconds;
+  }
+}
+
+
+/*
+** Mark the current time in all tasks so that we can use taskRestoreAll()
+** to restore the state of all tasks to where they are right now.
+** NOTE: this is intended to be used only with the timing elements.
+** Other stuff like annotations doesn't apply here, but annotations shouldn't
+** be added during idle time anyhow...
+*/
+void taskMarkAll ()
+{
+  int loop;
+
+  for ( loop = 0; loop <= max_task; loop++ ) {
+    if ( tasks[loop] ) {
+      taskMark ( tasks[loop] );
+    }
+  }
+}
+
+
+/*
+** Restore a task to its previous state when taskMark() was called.
+** This is intended to allow the application to bookmark the state
+** of a task and then return to it (as far as timing data goes).
+*/
+void taskRestore ( task )
+Task *task;
+{
+  int i;
+
+  for ( i = 0; i < task->num_entries; i++ ) {
+    task->entries[i]->seconds = task->entries[i]->marked_seconds;
+  }
+}
+
+
+
+/*
+** Restore all tasks to where they were when taskRestoreAll()
+** was called.
+*/
+void taskRestoreAll ()
+{
+  int loop;
+
+  for ( loop = 0; loop <= max_task; loop++ ) {
+    if ( tasks[loop] ) {
+      taskRestore ( tasks[loop] );
+    }
+  }
+}
+
+
+
 /*
 ** Delete a task.
 */
@@ -368,6 +464,7 @@ Task **task;
         temp[2] = '\0';
         entry->mday = atoi ( temp );
         entry->seconds = atoi ( line + 9 );
+        entry->marked_seconds = entry->seconds;
         if ( ! newtask->entries )
           newtask->entries = (TaskTimeEntry **) malloc ( 
             sizeof ( TaskTimeEntry * ) );
@@ -444,6 +541,32 @@ Task **task;
 int taskLoadAll ( taskdir )
 char *taskdir;
 {
+#ifdef WIN32
+   char *pattern;
+   Task *task;
+   long handle;
+   struct _finddata_t fdata;
+   pattern = malloc ( strlen ( taskdir ) + 8 );
+   (void) strcat ( strcpy ( pattern, taskdir ), "/*.task" );
+   if ( ( handle = _findfirst ( pattern, &fdata ) ) != -1 ) {
+     char *path = malloc ( strlen ( taskdir ) + _MAX_FNAME + 2 );
+     char *start = path + strlen ( taskdir ) + 1;
+     (void) strcat ( strcpy ( path, taskdir ), "/" );
+     do {
+       (void) strcpy ( start, fdata.name );
+       if ( valid_name ( fdata.name ) && !_access ( path, 4 ) ){
+         taskLoad ( path, &task );
+       }
+     } while ( !_findnext ( handle, &fdata ) );
+     _findclose ( handle );
+     free ( path );
+   }
+   else {
+     free ( pattern );
+     return ( TASK_ERROR_SYSTEM_ERROR );
+   }
+   free ( pattern );
+#else
   DIR *dir;
   struct dirent *entry;
   struct stat buf;
@@ -467,6 +590,7 @@ char *taskdir;
     free ( path );
   }
 
+#endif
   return ( 0 );
 }
 
@@ -478,12 +602,13 @@ int task_error;
 
   switch ( task_error ) {
     case TASK_ERROR_SYSTEM_ERROR:
-      sprintf ( msg, "System Error (%d)", errno );
+      sprintf ( msg, "%s (%d)", gettext("System Error"), errno );
       return ( msg );
     case TASK_ERROR_BAD_FILE:
-      return ( "Invalid task data file format" );
+      return ( gettext("Invalid task data file format") );
     default:
-      sprintf ( msg, "Unknown error(%d)", task_error );
+      sprintf ( msg, "%s(%d)", gettext("Unknown error"),
+        task_error );
       return ( msg );
   }
 }
@@ -538,6 +663,7 @@ int year, month, day;
   ret->mon = month;
   ret->mday = day;
   ret->seconds = 0;
+  ret->marked_seconds = 0;
 
   if ( task->entries )
     task->entries = (TaskTimeEntry **) realloc ( task->entries,
