@@ -2,7 +2,7 @@
  * Definition for a task
  *
  * Copyright:
- *	(C) 1998 Craig Knudsen, cknudsen@radix.net
+ *	(C) 1999 Craig Knudsen, cknudsen@radix.net
  *	See accompanying file "COPYING".
  * 
  *	This program is free software; you can redistribute it and/or
@@ -35,6 +35,7 @@
 typedef struct {
   int seconds;		/* time in seconds */
   int mon, mday, year;	/* MM/DD/YYYY */
+  int marked_seconds;	/* time in seconds - used by taskMark() */
 } TaskTimeEntry;
 
 typedef struct {
@@ -61,6 +62,10 @@ typedef struct {
 void taskAdd ( Task *task );
 int taskSave ( Task *task, char *taskdir );
 int taskSaveAll ( char *taskdir );
+void taskMark ( Task *task );
+void taskMarkAll ();
+void taskRestore ( Task *task );
+void taskRestoreAll ();
 void taskClearAll ();
 int taskLoad ( char *file, Task **task );
 int taskLoadAll ( char *taskdir );
